package xhttp3.internal.platform;

import java.lang.reflect.Field;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import xhttp3.OkHttpClient;
import xhttp3.Protocol;
import xhttp3.internal.tls.BasicCertificateChainCleaner;
import xhttp3.internal.tls.CertificateChainCleaner;
import xhttp3.internal.tls.TrustRootIndex;
import xio.Buffer;

public class Platform {
   private static final Platform PLATFORM = findPlatform();
   public static final int INFO = 4;
   public static final int WARN = 5;
   private static final Logger logger = Logger.getLogger(OkHttpClient.class.getName());

   public static Platform get() {
      return PLATFORM;
   }

   public static List<String> alpnProtocolNames(List<Protocol> protocols) {
      ArrayList var1;
      var1 = new ArrayList.<init>(protocols.size());
      int var2 = 0;

      for(int var3 = protocols.size(); var2 < var3; ++var2) {
         Protocol var4;
         if ((var4 = (Protocol)protocols.get(var2)) != Protocol.HTTP_1_0) {
            var1.add(var4.toString());
         }
      }

      return var1;
   }

   private static Platform findPlatform() {
      Platform var0;
      if ((var0 = AndroidPlatform.buildIfSupported()) != null) {
         return var0;
      } else {
         Jdk9Platform var1;
         if ((var1 = Jdk9Platform.buildIfSupported()) != null) {
            return var1;
         } else {
            return (var0 = JdkWithJettyBootPlatform.buildIfSupported()) != null ? var0 : new Platform();
         }
      }
   }

   static byte[] concatLengthPrefixed(List<Protocol> protocols) {
      Buffer var1;
      var1 = new Buffer.<init>();
      int var2 = 0;

      for(int var3 = protocols.size(); var2 < var3; ++var2) {
         Protocol var4;
         if ((var4 = (Protocol)protocols.get(var2)) != Protocol.HTTP_1_0) {
            var1.writeByte(var4.toString().length());
            var1.writeUtf8(var4.toString());
         }
      }

      return var1.readByteArray();
   }

   static <T> T readFieldOrNull(Object instance, Class<T> fieldType, String fieldName) {
      for(Class var3 = instance.getClass(); var3 != Object.class; var3 = var3.getSuperclass()) {
         Field var10000;
         boolean var10001;
         try {
            var10000 = var3.getDeclaredField(fieldName);
         } catch (NoSuchFieldException var11) {
            var10001 = false;
            continue;
         } catch (IllegalAccessException var12) {
            var10001 = false;
            throw new AssertionError();
         }

         Field var15 = var10000;

         Object var13;
         try {
            var15.setAccessible(true);
            var13 = var10000.get(instance);
         } catch (NoSuchFieldException var9) {
            var10001 = false;
            continue;
         } catch (IllegalAccessException var10) {
            var10001 = false;
            throw new AssertionError();
         }

         Object var4 = var13;
         if (var13 != null) {
            boolean var14;
            try {
               var14 = fieldType.isInstance(var4);
            } catch (NoSuchFieldException var7) {
               var10001 = false;
               continue;
            } catch (IllegalAccessException var8) {
               var10001 = false;
               throw new AssertionError();
            }

            if (var14) {
               try {
                  return fieldType.cast(var4);
               } catch (NoSuchFieldException var5) {
                  var10001 = false;
                  continue;
               } catch (IllegalAccessException var6) {
                  var10001 = false;
                  throw new AssertionError();
               }
            }
         }

         return null;
      }

      if (!fieldName.equals("delegate") && (instance = readFieldOrNull(instance, Object.class, "delegate")) != null) {
         return readFieldOrNull(instance, fieldType, fieldName);
      } else {
         return null;
      }
   }

   public String getPrefix() {
      return "OkHttp";
   }

   public X509TrustManager trustManager(SSLSocketFactory param1) {
      // $FF: Couldn't be decompiled
   }

   public void configureTlsExtensions(SSLSocket sslSocket, String hostname, List<Protocol> protocols) {
   }

   public void afterHandshake(SSLSocket sslSocket) {
   }

   public String getSelectedProtocol(SSLSocket socket) {
      return null;
   }

   public void connectSocket(Socket socket, InetSocketAddress address, int connectTimeout) {
      socket.connect(address, connectTimeout);
   }

   public void log(int level, String message, Throwable t) {
      Level var4;
      if (level == 5) {
         var4 = Level.WARNING;
      } else {
         var4 = Level.INFO;
      }

      logger.log(var4, message, t);
   }

   public boolean isCleartextTrafficPermitted(String hostname) {
      return true;
   }

   public CertificateChainCleaner buildCertificateChainCleaner(X509TrustManager trustManager) {
      return new BasicCertificateChainCleaner(TrustRootIndex.get(trustManager));
   }
}
